cmd

package
v0.2.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2025 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Types

type RunFlags

type RunFlags struct {
	config.ConfigOverrideFlags
	ConfigPath         string
	IsBatch            bool
	IsPerf             bool
	NoReport           bool
	ShowTableOnConsole bool
}

RunFlags holds the command line flags for the run command

func (*RunFlags) String

func (r *RunFlags) String() string

type TestContext

type TestContext struct {
	Config   *config.Config
	Provider provider.Provider
	Dataset  []provider.AnyParams
}

TestContext holds the context for running tests

func InitializeTest

func InitializeTest(flags *RunFlags) *TestContext

InitializeTest initializes the test environment based on command line flags and config

Jump to