Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type RunFlags ¶
type RunFlags struct {
config.ConfigOverrideFlags
ConfigPath string
IsBatch bool
IsPerf bool
NoReport bool
ShowTableOnConsole bool
}
RunFlags holds the command line flags for the run command
type TestContext ¶
type TestContext struct {
Config *config.Config
Provider provider.Provider
Dataset []provider.AnyParams
}
TestContext holds the context for running tests
func InitializeTest ¶
func InitializeTest(flags *RunFlags) *TestContext
InitializeTest initializes the test environment based on command line flags and config
Click to show internal directories.
Click to hide internal directories.